/*
 * Copyright (C) 2005 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License.
 * You must obey the GNU General Public License in all respects for all of the code used
 * other than the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.generator.tal.interfaces;

import java.util.Iterator;

public interface TALExpressionParser {
  public Object preparseExpression(String anExpression);
  public Object preparseStringExpression(String anExpression);
  public Object preparseBooleanExpression(String anExpression);
  public Object preparseReferenceExpression(String anExpression);
  public Object preparseListExpression(String anExpression);
  public Object preparseTRUE();
  public Object preparseFALSE();

  public Object evaluateExpression(Object aContext, Object aPreparsedExpression);
  public String evaluateStringExpression(Object aContext, Object aPreparsedExpression);
  public boolean evaluateBooleanExpression(Object aContext, Object aPreparsedExpression);
  public Iterator evaluateListExpression(Object aContext, Object aPreparsedExpression);
  public void processAssignment(Object aContext, Object aPreparsedReferenceExpression, Object aPreparsedExpression);

  /**
   * process a direct assignment of an object to a preparsed reference expression
   *
   */
  public void processDirectAssignment(Object aContext, Object aPreparsedReferenceExpression, Object aValue);

  /**
   * process an assigment to a pseudo variable. The pseudo variable will have a java
   *   identifier-like name.
   *
   */
  public void processPseudoAssignment(Object aContext, String aName, Object aValue);

  /**
   * Retrieve the value of a pseudo variable
   *
   */
  public Object evaluatePseudoVariable(Object aContext, String aName);

}