/*
 * Copyright (C) 2005 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License.
 * You must obey the GNU General Public License in all respects for all of the code used
 * other than the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.generator.tal.interfaces;

public interface TALLogger {
  public void debug(String anObject, String aMessage);
  public void info(String anObject, String aMessage);
  public void warning(String anObject, String aMessage);
  public void error(String anObject, String aMessage);
  public void fatal(String anObject, String aMessage);

  /**
   * Simple logging class that logs everything to System.out
   */
  public class TALSystemOutLogger implements TALLogger {
    public TALSystemOutLogger() {
    }

    public void debug(String anObject, String aMessage) {
      System.out.println("DEBUG: " + anObject + "  " + aMessage);
    }

    public void info(String anObject, String aMessage) {
      System.out.println("INFO: " + anObject + "  " + aMessage);
    }

    public void warning(String anObject, String aMessage) {
      System.out.println("WARNING: " + anObject + "  " + aMessage);
    }

    public void error(String anObject, String aMessage) {
      System.out.println("ERROR: " + anObject + "  " + aMessage);
    }

    public void fatal(String anObject, String aMessage) {
      System.out.println("FATAL: " + anObject + "  " + aMessage);
    }
  }

  /**
   * Simple logging class that discards all logging information.
   */
  public class TALVoidLogger implements TALLogger {
    public void debug(String anObject, String aMessage) {
    }

    public void info(String anObject, String aMessage) {
    }

    public void warning(String anObject, String aMessage) {
    }

    public void error(String anObject, String aMessage) {
    }

    public void fatal(String anObject, String aMessage) {
    }
  }
}