/*
 * Copyright (C) 2005 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License.
 * You must obey the GNU General Public License in all respects for all of the code used
 * other than the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */
package mir.generator.tal.template;

import java.util.Map;

import mir.generator.tal.interfaces.TALExpressionParser;
import mir.generator.tal.interfaces.TALLogger;

/**
 * Simple <code>TemplateNode</code> that just outputs a fixed
 * piece of allText.
 */
public class PlainTextTemplateNode implements TemplateNode {
  private String allText;
  private String plainText;

  public PlainTextTemplateNode() {
    this("", "");
  }

  public PlainTextTemplateNode(String aText, String aPlainText) {
    allText = aText;
    plainText = aPlainText;
  }

  /** Appends text at the end */
  public void appendText(String aText) {
    allText = allText + aText;
  }

  /** Appends allText at the end */
  public void appendPlainText(String aText) {
    plainText = plainText + aText;
  }

  public String getText() {
    return allText;
  }

  public String getPlainText() {
    return plainText;
  }

  public void process(TALExpressionParser aParser, Object aContext,
      StringBuffer aDestination, TALLogger aLogger,
      Map aTemplateContext, TemplateLibrary aLibrary) throws TemplateProcessingException {
    aDestination.append(allText);
  }
}
