package mircoders.abuse;

import mir.entity.Entity;
import mir.session.Request;

import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

/**
  * Instances of this filter type will match if the filter expression is a substringo
 *  of the value(s) tested agains
  */
 public class SubStringFilterType extends AbstractFilterType {
    private boolean exactMatch;
    private boolean caseSensitive;
    private int fieldKind;
    private List selectedFields;

    public static final int ENTITY_FIELDS = 0;
    public static final int REQUEST_HEADERS = 2;

    public SubStringFilterType(String aName) {
      this(aName, false, false, null);
    }

    public SubStringFilterType(String aName, boolean aCaseSensitive, boolean anExactMatch, String[] aSelectedFields) {
      this (aName, aCaseSensitive, anExactMatch, ENTITY_FIELDS, aSelectedFields);
    }

    public SubStringFilterType(String aName, boolean aCaseSensitive, boolean anExactMatch, int aFieldKind, String[] aSelectedFields) {
      super(aName);

      fieldKind = aFieldKind;

      caseSensitive = aCaseSensitive;
      exactMatch = anExactMatch;
      if (aSelectedFields==null) {
        selectedFields = null;
      }
      else {
        selectedFields = Arrays.asList(aSelectedFields);
      }
    }


  public FilterInstance constructFilterInstance(final String anExpression) throws AbuseExc {
    return new FilterInstance() {
      public boolean test(Entity anEntity, Request aRequest) {
        Iterator j;
        String expression = anExpression;
        if (!caseSensitive) {
          expression = anExpression.toUpperCase();
        }

        switch (fieldKind) {
          case REQUEST_HEADERS:
            if (selectedFields != null) {
              j = selectedFields.iterator();

              while (j.hasNext()) {
                String fieldName = (String) j.next();
                String field = aRequest.getHeader(fieldName);
                if (test(field, expression)) {
                  return true;
                }
              }
            }
            break;

          case ENTITY_FIELDS:
            if (selectedFields != null) {
              j = selectedFields.iterator();
            }
            else {
              j = anEntity.getFieldNames().iterator();
            }

            while (j.hasNext()) {
              String field = anEntity.getFieldValue( (String) j.next());

              if (test(field, expression)) {
                return true;
              }
            }
        }
        return false;
      }

      private boolean test(String aValue, String anExpression) {
        if (!caseSensitive) {
          aValue=aValue.toUpperCase();
        }

        if (exactMatch) {
          if (aValue!= null && aValue.equals(anExpression)) {
            return true;
          }
        }
        else {
          if (aValue!= null && aValue.indexOf(anExpression)>=0) {
            return true;
          }
        }

        return false;
      }

      public String status() {
        return null;
      }
    };
  }
}
