/*
 * Copyright (C) 2001, 2002 The Mir-coders group
 *
 * This file is part of Mir.
 *
 * Mir is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Mir is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Mir; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * In addition, as a special exception, The Mir-coders gives permission to link
 * the code of this program with  any library licensed under the Apache Software License,
 * The Sun (tm) Java Advanced Imaging library (JAI), The Sun JIMI library
 * (or with modified versions of the above that use the same license as the above),
 * and distribute linked combinations including the two.  You must obey the
 * GNU General Public License in all respects for all of the code used other than
 * the above mentioned libraries.  If you modify this file, you may extend this
 * exception to your version of the file, but you are not obligated to do so.
 * If you do not wish to do so, delete this exception statement from your version.
 */

package mircoders.localizer;

import mir.entity.adapter.EntityAdapterModel;
import mir.generator.Generator;
import mir.generator.WriterEngine;

/**
 * This was used to prevent localizers from being created
 * all the time.
 * 
 */
public class LocalizerCache implements MirLocalizer {
  private MirLocalizer localizer;
  private MirProducerLocalizer producerLocalizer;
  private MirGeneratorLocalizer generatorLocalizer;
  private MirOpenPostingLocalizer openPostingsLocalizer;
  private MirProducerAssistantLocalizer producerAssistantLocalizer;
  private MirDataModelLocalizer dataModelLocalizer;
  private MirAdminInterfaceLocalizer adminInterfaceLocalizer;
  private MirMediaLocalizer mediaLocalizer;

  public LocalizerCache(MirLocalizer aLocalizer) {
    localizer = aLocalizer;
  }

  public MirProducerLocalizer producers() throws MirLocalizerFailure {
    if (producerLocalizer==null) {
      producerLocalizer = localizer.producers();
    }

    return producerLocalizer;
  }

  public MirGeneratorLocalizer generators() throws MirLocalizerFailure {
    if (generatorLocalizer==null) {
      generatorLocalizer = new MirCachingGeneratorLocalizer(localizer.generators());
    }

    return generatorLocalizer;
  }

  public MirOpenPostingLocalizer openPostings() throws MirLocalizerFailure {
    if (openPostingsLocalizer==null) {
      openPostingsLocalizer = localizer.openPostings();
    }

    return openPostingsLocalizer;
  }

  public MirProducerAssistantLocalizer producerAssistant() throws MirLocalizerFailure {
    if (producerAssistantLocalizer==null) {
      producerAssistantLocalizer = localizer.producerAssistant();
    }

    return producerAssistantLocalizer;
  }

  public MirDataModelLocalizer dataModel() throws MirLocalizerFailure {
    if (dataModelLocalizer==null) {
      dataModelLocalizer = new MirCachingDatamodelLocalizer(localizer.dataModel());
    }

    return dataModelLocalizer;
  }

  public MirAdminInterfaceLocalizer adminInterface() throws MirLocalizerFailure {
    if (adminInterfaceLocalizer==null) {
      adminInterfaceLocalizer = localizer.adminInterface();
    }

    return adminInterfaceLocalizer;
  }

  public MirMediaLocalizer media() throws MirLocalizerFailure {
    if (mediaLocalizer==null) {
      mediaLocalizer = localizer.media();
    }

    return mediaLocalizer;
  }

  private static class MirCachingDatamodelLocalizer implements MirDataModelLocalizer {
    private MirDataModelLocalizer master;
    private EntityAdapterModel adapterModel;

    public MirCachingDatamodelLocalizer(MirDataModelLocalizer aMaster) {
      master = aMaster;
      adapterModel = null;
    }

    public EntityAdapterModel adapterModel() throws MirLocalizerExc, MirLocalizerFailure {
      if (adapterModel==null) {
        adapterModel = master.adapterModel();
      }

      return adapterModel;
    }
  }

  private static class MirCachingGeneratorLocalizer implements MirGeneratorLocalizer {
    private MirGeneratorLocalizer master;
    private WriterEngine writerEngine;
    private Generator.Library producerGeneratorLibrary;
    private Generator.Library adminGeneratorLibrary;
    private Generator.Library openPostingGeneratorLibrary;

    public MirCachingGeneratorLocalizer(MirGeneratorLocalizer aMaster) {
      master = aMaster;
    }

    public WriterEngine makeWriterEngine() throws MirLocalizerExc, MirLocalizerFailure {
      if (writerEngine==null) {
        writerEngine = master.makeWriterEngine();
      }

      return writerEngine;
    }

    public Generator.Library makeProducerGeneratorLibrary() throws MirLocalizerExc, MirLocalizerFailure {
      if (producerGeneratorLibrary==null) {
        producerGeneratorLibrary = master.makeProducerGeneratorLibrary();
      }

      return producerGeneratorLibrary;
    }

    public Generator.Library makeAdminGeneratorLibrary() throws MirLocalizerExc, MirLocalizerFailure {
      if (adminGeneratorLibrary==null) {
        adminGeneratorLibrary = master.makeAdminGeneratorLibrary();
      }

      return adminGeneratorLibrary;
    }

    public Generator.Library makeOpenPostingGeneratorLibrary() throws MirLocalizerExc, MirLocalizerFailure {
      if (openPostingGeneratorLibrary==null) {
        openPostingGeneratorLibrary = master.makeOpenPostingGeneratorLibrary();
      }

      return openPostingGeneratorLibrary;
    }
  }

}